import {
  ChangeDetectionStrategy,
  Component,
  Input,
  Output,
} from "@angular/core";
import {SharedAbstractPresentational} from "@app/shared/components/presentationals/shared-abstract/shared-abstract.presentational";
import {LanguagesEnum} from "@app/shared/enums/languages.enum";
import {
  BehaviorSubject,
  Observable,
} from "rxjs";
import {ObservableUtil} from "solidify-frontend";

@Component({
  selector: "dlcm-language-selector",
  templateUrl: "./language-selector.presentational.html",
  styleUrls: ["./language-selector.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class LanguageSelectorPresentational extends SharedAbstractPresentational {
  @Input()
  currentLanguage: LanguagesEnum;

  private readonly _languageBS: BehaviorSubject<LanguagesEnum | undefined> = new BehaviorSubject<LanguagesEnum | undefined>(undefined);

  @Output("languageChange")
  readonly languageObs: Observable<LanguagesEnum | undefined> = ObservableUtil.asObservable(this._languageBS);

  get languagesEnum(): typeof LanguagesEnum {
    return LanguagesEnum;
  }

  constructor() {
    super();
  }

  useLanguage(language: LanguagesEnum): void {
    this._languageBS.next(language);
  }
}
